@@ -39,6 +39,11 @@ function Map:Map(app)
   self.debug_font = false
   self.debug_tick_timer = 1
   self:setTemperatureDisplayMethod(app.config.warmth_colors_display_default)
+
+  -- Difficulty of the level (string) "easy", "full", "hard".
+  -- Use map:getDifficulty() to query the value.
+  self.difficulty = nil
+  self.hotfix1 = true
 end
 
 local flag_cache = {}
@@ -277,6 +282,14 @@ function Map:load(level, difficulty, level_name, map_file, level_intro, map_edit
   return objects
 end
 
+--! Get the difficulty of the level. Custom levels and campaign always have medium difficulty.
+--!return (int) difficulty of the level, 1=easy, 2=medium, 3=hard.
+function Map:getDifficulty()
+  if self.difficulty == "easy" then return 1 end
+  if self.difficulty == "hard" then return 3 end
+  return 2
+end
+
 --[[! Sets the plot owner of the given plot number to the given new owner. Makes sure
       that any room adjacent to the new plot have walls in all directions after the purchase.
 !param plot_number (int) Number of the plot to change owner of. Plot 0 is the outside and
@@ -726,6 +739,24 @@ function Map:getParcelTileCount(parcel)
   return self.parcelTileCounts[parcel] or 0
 end
 
+--! Apply a hotfix to this save..
+--! Note this is only temporary as a backport for 0.65
+--!param num (int) the hotfix number
+--!param issue (num) the issue number
+function Map:applyHotfix(num, issue)
+  assert((num and issue), "Hotfix parameters given are undefined!")
+  if num == 1 then
+    self.level_config.awards_trophies.TrophyAllCuredBonus = 20000
+    self.level_config.awards_trophies.AllCuresBonus = 5000
+    self.hotfix1 = true
+    local string = "Game successfully patched with hotfix " .. num .. " (Issue #" .. issue .. ")"
+    self.app.world:gameLog(string)
+  else
+    local string = "Hotfix " .. num .. " not found. The game may result in unexpected behavior."
+    self.app.world:gameLog(string)
+  end
+end
+
 function Map:afterLoad(old, new)
   if old < 6 then
     self.parcelTileCounts = {}
@@ -790,4 +821,8 @@ function Map:afterLoad(old, new)
       self:setCellFlags(58, 72, {passable = false})
     end
   end
+  -- 0.65 has a hotfix, make sure we patch any affected games
+  if not self.hotfix1 then
+    self:applyHotfix(1, 2004)
+  end
 end
